@@ -1,4 +1,4 @@
-# Copyright (C) 2003 Jean-Pierre Gattuso and Aurelien Proye
+# Copyright (C) 2008 Jean-Pierre Gattuso and Héloïse Lavigne and Aurelien Proye
 #
 # This file is part of seacarb.
 #
@@ -9,21 +9,24 @@
 # You should have received a copy of the GNU General Public License along with seacarb; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 "K1" <-
-function(S=35,T=25,P=0,k1k2='r',phflag=0){
+function(S=35,T=25,P=0,k1k2='l')
+{
+
+nK <- max(length(S), length(T), length(P), length(k1k2))
+
+##-------- Creation de vecteur pour toutes les entrees (si vectorielles)
+
+if(length(S)!=nK){S <- rep(S[1], nK)}
+if(length(T)!=nK){T <- rep(T[1], nK)}
+if(length(P)!=nK){P <- rep(P[1], nK)}
+if(length(k1k2)!=nK){k1k2 <- rep(k1k2[1], nK)}
+
 
-if (k1k2=='m')
-{
-k1k2flag=1;
-}
-if (k1k2=='r')
-{
-k1k2flag=0;
-}
 #-------Constantes----------------
 
 #---- issues de equic----
 tk = 273.15;           # [K] (for conversion [deg C] <-> [K])
-TC = T + tk;           # TC [C]; T[K]
+TK = T + tk;           # TC [C]; T[K]
 Cl = S / 1.80655;      # Cl = chlorinity; S = salinity (per mil)
 cl3 = Cl^(1/3);   
 ION = 0.00147 + 0.03592 * Cl + 0.000068 * Cl * Cl;   # ionic strength
@@ -33,7 +36,20 @@ ST = 0.14/96.062/1.80655*S;   # (mol/kg soln) total sulfate
 
 bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94   
 
+# --------------------- K1 ---------------------------------------
+#   first acidity constant:
+#   [H^+] [HCO_3^-] / [CO2] = K_1
+#
+#     Mehrbach et al (1973) refit by Lueker et al. (2000).
+#
+#(Lueker  et al., 2000 in Guide to the Best Practices for Ocean CO2 Measurements
+#   Dickson, Sabin and Christian , 2007, Chapter 5, p. 13)
+#
+#   pH-scale: 'total'. mol/kg-soln
 	
+logK1lue <- (-3633.86)/TK + 61.2172 - 9.67770*log(TK) + 0.011555*S - 0.0001152*S*S
+K1lue <- 10^logK1lue
+
 # --------------------- K1 ---------------------------------------
 #   first acidity constant:
 #   [H^+] [HCO_3^-] / [CO2] = K_1
@@ -41,68 +57,34 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 #   (Roy et al., 1993 in Dickson and Goyet, 1994, Chapter 5, p. 14)
 #   pH-scale: 'total'. mol/kg-soln
 
-tmp1 = 2.83655 - 2307.1266 / TC - 1.5529413 * log(TC);
-tmp2 =         - (0.20760841 + 4.0484 / TC) * sqrt(S);
+tmp1 = 2.83655 - 2307.1266 / TK - 1.5529413 * log(TK);
+tmp2 =         - (0.20760841 + 4.0484 / TK) * sqrt(S);
 tmp3 =         + 0.08468345 * S - 0.00654208 * S * sqrt(S);   
 tmp4 =         + log(1 - 0.001005 * S);
 
 lnK1roy = tmp1 + tmp2 + tmp3 + tmp4;
 
-if (phflag == 0)
-{
         K1roy  = exp(lnK1roy);
-}
-if (phflag == 1)
-{
-        lnK1roy = lnK1roy-log(total2free);
-        K1roy   = exp(lnK1roy);
-}
-	
-		
-# --------------------- K1 ---------------------------------------
-#   first acidity constant:
-#   [H^+] [HCO_3^-] / [H_2CO_3] = K_1
-#
-#   Mehrbach et al (1973) refit by Lueker et al. (2000).
-#
-#   pH-scale: 'total'. mol/kg-soln
 
-pK1mehr = 3633.86/TC - 61.2172 + 9.6777*log(TC) - 0.011555*S + 0.0001152*S*S;
-	
-if (phflag == 0)
-{
-        K1mehr  = 10^(-pK1mehr);
-}
-if (phflag == 1)
-{
-	lnK1mehr = log(10^(-pK1mehr))-log(total2free);
-        K1mehr   = exp(lnK1mehr);
-}
-	
-#----------- Roy or Mehrbach. default: Roy 
 
-K1 = K1roy;
-	
-if (exists('k1k2flag'))
-{
-	if (k1k2flag == 0)
-	{	
-	K1 = K1roy;
-	}
-	if (k1k2flag == 1)
-	{
-	K1 = K1mehr;
-	}
-	
+# ---------- Choice between methods (Lueker or Roy) ----------
+
+K1 <- K1lue
+
+for(i in (1:nK)){
+if(k1k2[i]=='l'){K1[i] <- K1lue[i] }
+if(k1k2[i]=='r'){K1[i] <- K1roy[i] }
 }
-	
-if (P > 0.0)
+
+# ------------------- Pression effect --------------------------------
+for(i in (1:nK)){
+if (P[i] > 0.0)
 {
 		
 	RGAS = 8.314510;        # J mol-1 deg-1 (perfect Gas)  
 	R = 83.131;             # mol bar deg-1 
 	                        # conversion cm3 -> m3          *1.e-6
-        	                #            bar -> Pa = N m-2  *1.e+5
+        	                  #            bar -> Pa = N m-2  *1.e+5
 	                        #                => *1.e-1 or *1/10
 		
 		
@@ -132,14 +114,15 @@ if (P > 0.0)
 	
 	for (ipc in 1:length(a0))
 	{
-	  deltav[ipc]  =  a0[ipc] + a1[ipc] *T + a2[ipc] *T*T;
-	  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T + b2[ipc] *T*T);  
-	  lnkpok0[ipc]  = -(deltav[ipc] /(R*TC))*P + (0.5*deltak[ipc] /(R*TC))*P*P;
+	  deltav[ipc]  =  a0[ipc] + a1[ipc] *T[i] + a2[ipc] *T[i]*T[i];
+	  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T[i] + b2[ipc] *T[i]*T[i]);  
+	  lnkpok0[ipc]  = -(deltav[ipc] /(R*TK[i]))*P[i] + (0.5*deltak[ipc] /(R*TK[i]))*P[i]*P[i];
 	}
 	
-	K1 = K1*exp(lnkpok0[1]);
+	K1[i] = K1[i]*exp(lnkpok0[1]);
 		
-	}
+}
+}
 attr(K1,"unit")     = "mol/kg-soln"
 attr(K1,"pH scale") = "total hydrogen ion concentration"
 return(K1)
