@@ -1,4 +1,4 @@
-# Copyright (C) 2003 Jean-Pierre Gattuso and Aurelien Proye
+# Copyright (C) 2008 Jean-Pierre Gattuso and Héloïse Lavigne and Aurelien Proye
 #
 # This file is part of seacarb.
 #
@@ -16,7 +16,7 @@ function(S=35,T=25,P=0){
 
 #---- issues de equic----
 tk = 273.15;           # [K] (for conversion [deg C] <-> [K])
-TC = T + tk;           # TC [C]; T[K]
+TK = T + tk;           # T [C]; TK[K]
 Cl = S / 1.80655;      # Cl = chlorinity; S = salinity (per mille)
 cl3 = Cl^(1/3);   
 ION = 0.00147 + 0.03592 * Cl + 0.000068 * Cl * Cl;   # ionic strength
@@ -27,12 +27,13 @@ ST = 0.14/96.062/1.80655*S;   # (mol/kg soln) total sulfate
 bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94   
 
 	# --------------------- Phosphoric acid ---------------------
-	#	#
-	#   (DOE, 1994)  (Dickson and Goyet): pH_T, mol/(kg-soln)
-	#   Ch.5 p. 16
+	#
+	#   Guide to Best Practices in Ocean CO2 Measurements 2007 Chap 5 p 15 
+	#  
+	#   Ch.5 p. 15
 	#
 		
-	lnK3P = -3070.75 / TC - 18.141 + (17.27039 / TC + 2.81197) * sqrt(S) + (-44.99486 / TC - 0.09984) * S;
+	lnK3P = -3070.75 / TK - 18.141 + (17.27039 / TK + 2.81197) * sqrt(S) + (-44.99486 / TK - 0.09984) * S;
 	
 	K3P = exp(lnK3P);
 	
@@ -41,9 +42,9 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 		
 		RGAS = 8.314510;        # J mol-1 deg-1 (perfect Gas)  
 		R = 83.131;             # mol bar deg-1 
-		                        # conversion cm3 -> m3          *1.e-6
-	                        #            bar -> Pa = N m-2  *1.e+5
-		                        #                => *1.e-1 or *1/10
+		                        # conversion cm3 -> m3     *1.e-6
+	                      		# bar -> Pa = N m-2  *1.e+5
+		                        #     => *1.e-1 or *1/10
 		
 		
 		# index: K1 1, K2 2, Kb 3, Kw 4, Ks 5, Kf 6, Kspc 7, Kspa 8,
@@ -72,7 +73,7 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 		{
 		  deltav[ipc]  =  a0[ipc] + a1[ipc] *T + a2[ipc] *T*T;
 		  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T + b2[ipc] *T*T);  
-		  lnkpok0[ipc]  = -(deltav[ipc] /(R*TC))*P + (0.5*deltak[ipc] /(R*TC))*P*P;
+		  lnkpok0[ipc]  = -(deltav[ipc] /(R*TK))*P + (0.5*deltak[ipc] /(R*TK))*P*P;
 		}
 		
 
